Name:		openvkl
Version:	1.3.2
Release:	%autorelease
Summary:	Intel(R) Open Volume Kernel Library

License:	Apache-2.0
URL:		https://github.com/OpenVKL/openvkl
Source0:	%{url}/archive/v%{version}/%{name}-%{version}.tar.gz

# https://github.com/openvkl/openvkl/pull/18
Patch0:		cmake.patch

BuildRequires:	boost-devel
BuildRequires:	blosc-devel
BuildRequires:	cmake3
BuildRequires:	embree-devel
BuildRequires:	gcc-c++
BuildRequires:	glfw-devel
BuildRequires:	imath-devel
BuildRequires:	ispc
BuildRequires:	openvdb-devel
BuildRequires:	rkcommon-devel
BuildRequires:	tbb-devel
BuildRequires:	zlib-devel

# Upstream only supports x86_64 and ARM64 architectures
ExclusiveArch:	aarch64 x86_64

%description
Intel® Open Volume Kernel Library (Intel® Open VKL) is a collection of 
high-performance volume computation kernels, developed at Intel. The target
users of Open VKL are graphics application engineers who want to improve the
performance of their volume rendering applications by leveraging Open VKL’s
performance-optimized kernels, which include volume traversal and sampling
functionality for a variety of volumetric data formats.

The kernels are optimized for the latest Intel® processors with support for 
SSE, AVX, AVX2, and AVX-512 instructions, and for ARM processors with support
for NEON instructions.

%package devel
Summary:	Development files for %{name}
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
applications that use %{name}.

%prep
%autosetup -p1

# do not install LICENSE.txt
sed -i '/LICENSE.txt/d' openvkl/CMakeLists.txt
# lib64 path fix 
sed -i 's/lib\/cmake/%{_lib}\/cmake/g' utility/vdb/CMakeLists.txt

%build
%cmake \
	-DOpenVDB_ROOT=/usr \
	-DBUILD_EXAMPLES=OFF \
	-DBUILD_BENCHMARKS=OFF \
	-DOPENVKL_DEVICE_CPU_VDB=OFF
%cmake_build

%install
%cmake_install

%check
%ctest

%files
%license LICENSE.txt
%doc CHANGELOG.md README.md third-party-programs*.txt
%{_bindir}/vklTests
%{_libdir}/lib%{name}.so.%{version}
%{_libdir}/lib%{name}.so.1
%{_libdir}/lib%{name}_module_cpu_device.so.%{version}
%{_libdir}/lib%{name}_module_cpu_device.so.1
%{_libdir}/lib%{name}_module_cpu_device_*.so.%{version}
%{_libdir}/lib%{name}_module_cpu_device_*.so.1

%files devel
%{_includedir}/%{name}
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}_module_cpu_device.so
%{_libdir}/lib%{name}_module_cpu_device_*.so
%{_libdir}/cmake/%{name}-%{version}/

%changelog
%autochangelog
